==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/QGpCoreMath/src/QGpCoreMath.h <==
#ifndef QGPCOREMATH_HEADERS
#define QGPCOREMATH_HEADERS

// All headers of QGpCoreMath library

#include "AbstractColorPalette.h"
#include "AbstractComplexPointOptions.h"
#include "AbstractFunction.h"
#include "AbstractNumericalCache.h"
#include "AbstractNumericalKey.h"
#include "Angle.h"
#include "AngleSearch.h"
#include "AverageAngle.h"
#include "BasicCurveProxy.h"
#include "Circle.h"
#include "ColorMap.h"
#include "ColorMapData.h"
#include "ColorPalette.h"
#include "ComplexExponential.h"
#include "ComplexMPMatrix.h"
#include "ComplexMatrix.h"
#include "ComplexPointOptions.h"
#include "ComplexStatisticalProxy.h"
#include "ConcentricSearch.h"
#include "CoordinateFile.h"
#include "Covariance.h"
#include "Curve.h"
#include "CurvePointOptions.h"
#include "CurveProxy.h"
#include "CurveSplitter.h"
#include "DirectionalSearch.h"
#include "DoubleMatrix.h"
#include "Ellipse.h"
#include "FunctionSearch.h"
#include "GaussDistribution.h"
#include "GoogleEarthKML.h"
#include "Grid2D.h"
#include "Grid3D.h"
#include "GridParallelWriter.h"
#include "GridSearch.h"
#include "GridSearchTest.h"
#include "Histogram.h"
#include "Histogram2D.h"
#include "IrregularGrid2D.h"
#include "IrregularGrid2DData.h"
#include "LeastSquare.h"
#include "Line2D.h"
#include "LinearRegression.h"
#include "Matrix.h"
#include "MatrixIterator.h"
#include "MatrixMultiply.h"
#include "NamedPoint.h"
#include "Parallelepiped.h"
#include "PermutationVector.h"
#include "Plane.h"
#include "Point.h"
#include "Point1D.h"
#include "Point2D.h"
#include "PointLocate.h"
#include "PointND.h"
#include "PointNDOptions.h"
#include "ProcessStatistics.h"
#include "QGpCoreMathDLLExport.h"
#include "Random.h"
#include "RealStatisticalProxy.h"
#include "Rect.h"
#include "RootSolver.h"
#include "SamplingParameters.h"
#include "Scale.h"
#include "Segment.h"
#include "Segment2D.h"
#include "Simplex.h"
#include "SmoothingParameters.h"
#include "SparseMatrix.h"
#include "StatComparator.h"
#include "Stationarity.h"
#include "StatisticalPoint.h"
#include "StatisticalValue.h"
#include "Statistics.h"
#include "UtmZone.h"
#include "Value.h"
#include "WindowFunction.h"
#include "WindowFunctionParameters.h"
#include "XUniqueYColorData.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpCoreMath;
#endif

#endif // QGPCOREMATH_HEADERS

==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/QGpCoreMath/src/QGpCoreMath.h <==
#ifndef QGPCOREMATH_HEADERS
#define QGPCOREMATH_HEADERS

// All headers of QGpCoreMath library

#include "AbstractColorPalette.h"
#include "AbstractComplexPointOptions.h"
#include "AbstractFunction.h"
#include "AbstractNumericalCache.h"
#include "AbstractNumericalKey.h"
#include "Angle.h"
#include "AngleSearch.h"
#include "AverageAngle.h"
#include "BasicCurveProxy.h"
#include "ChiSquareTest.h"
#include "Circle.h"
#include "Cluster.h"
#include "ColorMap.h"
#include "ColorMapData.h"
#include "ColorPalette.h"
#include "ComplexExponential.h"
#include "ComplexMPMatrix.h"
#include "ComplexMatrix.h"
#include "ComplexPointOptions.h"
#include "ComplexStatisticalProxy.h"
#include "ConcentricSearch.h"
#include "CoordinateFile.h"
#include "Covariance.h"
#include "Curve.h"
#include "CurvePointOptions.h"
#include "CurveProxy.h"
#include "CurveSplitter.h"
#include "DelaunayTriangulation.h"
#include "DirectionalSearch.h"
#include "DoubleMatrix.h"
#include "Ellipse.h"
#include "FrequencyBand.h"
#include "FunctionSearch.h"
#include "GaussDistribution.h"
#include "GaussianFrequencyBand.h"
#include "GoogleEarthKML.h"
#include "Grid2D.h"
#include "Grid3D.h"
#include "GridParallelWriter.h"
#include "GridSearch.h"
#include "GridSearchTest.h"
#include "IrregularGrid2D.h"
#include "IrregularGrid2DData.h"
#include "LeastSquare.h"
#include "Line2D.h"
#include "LinearRegression.h"
#include "Matrix.h"
#include "MatrixIterator.h"
#include "MatrixMultiply.h"
#include "NamedPoint.h"
#include "Parallelepiped.h"
#include "PermutationVector.h"
#include "Plane.h"
#include "Point.h"
#include "Point1D.h"
#include "Point2D.h"
#include "PointLocate.h"
#include "PointND.h"
#include "PointNDOptions.h"
#include "PrimeFactorization.h"
#include "ProcessStatistics.h"
#include "QGpCoreMathDLLExport.h"
#include "Random.h"
#include "RealStatisticalProxy.h"
#include "Rect.h"
#include "RootSolver.h"
#include "SamplingParameters.h"
#include "Scale.h"
#include "Segment.h"
#include "Segment2D.h"
#include "Simplex.h"
#include "SmoothingParameters.h"
#include "SparseMatrix.h"
#include "Sphere.h"
#include "StatComparator.h"
#include "Stationarity.h"
#include "StatisticalPoint.h"
#include "StatisticalValue.h"
#include "Statistics.h"
#include "Triangle.h"
#include "TriangularMatrix.h"
#include "UtmZone.h"
#include "Value.h"
#include "Vector.h"
#include "WindowFunction.h"
#include "WindowFunctionParameters.h"
#include "XUniqueYColorData.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace QGpCoreMath;
#endif

#endif // QGPCOREMATH_HEADERS
